#[repr(i32)]pub enum JitterPolicy {
Unspecified = 0,
None = 1,
Full = 2,
Equal = 3,
Decorrelated = 4,
}Expand description
Randomness added to each backoff delay to avoid retry storms. “base” is the delay computed by BackoffPolicy before jitter.
Variants
Unspecified = 0
no jitter policy
None = 1
exact base, no randomness
Full = 2
uniform in [0, base]
Equal = 3
centered near base/2
min(max, rand(base * 3))
Implementations
Sourceimpl JitterPolicy
impl JitterPolicy
Sourceimpl JitterPolicy
impl JitterPolicy
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.