#[repr(i32)]pub enum RestartPolicy {
Unspecified = 0,
Never = 1,
OnFailure = 2,
Always = 3,
}Expand description
When to restart a task after an attempt ends.
Variants
Unspecified = 0
no restart policy
Never = 1
never restart
OnFailure = 2
restart only on failure or non-zero exit
Always = 3
always restart; waits restart_interval_ms
Implementations
Sourceimpl RestartPolicy
impl RestartPolicy
Sourceimpl RestartPolicy
impl RestartPolicy
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.