#[repr(i32)]pub enum SelectorOperator {
Unspecified = 0,
In = 1,
NotIn = 2,
Exists = 3,
DoesNotExist = 4,
}Expand description
Comparison operator for one selector requirement.
Variants
Unspecified = 0
no selector operator
In = 1
label value must be one of values
NotIn = 2
label value must not be one of values
Exists = 3
label key must exist; values must be empty
DoesNotExist = 4
label key must not exist; values must be empty
Implementations
Sourceimpl SelectorOperator
impl SelectorOperator
Sourcepub const fn is_valid(value: i32) -> bool
pub const fn is_valid(value: i32) -> bool
Returns true if value is a variant of SelectorOperator.
Sourcepub fn from_i32(value: i32) -> Option<SelectorOperator>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<SelectorOperator>
Use the TryFrom<i32> implementation instead
Converts an i32 to a SelectorOperator, or None if value is not a valid variant.
Sourceimpl SelectorOperator
impl SelectorOperator
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.