#[repr(i32)]pub enum TaskWatchEventType {
Unspecified = 0,
Added = 1,
Modified = 2,
Deleted = 3,
}Expand description
Task collection watch event type.
Variants
Unspecified = 0
no event type
Added = 1
Task entered the watched collection
Modified = 2
watched Task changed
Deleted = 3
Task left the watched collection
Implementations
Sourceimpl TaskWatchEventType
impl TaskWatchEventType
Sourcepub const fn is_valid(value: i32) -> bool
pub const fn is_valid(value: i32) -> bool
Returns true if value is a variant of TaskWatchEventType.
Sourcepub fn from_i32(value: i32) -> Option<TaskWatchEventType>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<TaskWatchEventType>
Use the TryFrom<i32> implementation instead
Converts an i32 to a TaskWatchEventType, or None if value is not a valid variant.
Sourceimpl TaskWatchEventType
impl TaskWatchEventType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.