pub struct BackoffPolicy {
pub jitter: i32,
pub first_ms: u64,
pub max_ms: u64,
pub factor: f64,
}Expand description
Exponential backoff between restart attempts.
Fields
jitter: i32jitter applied to each delay
first_ms: u64initial delay (ms); must be > 0
max_ms: u64delay cap (ms); must be >= first_ms
factor: f64growth multiplier; must be finite and >= 1.0
Implementations
Sourceimpl BackoffPolicy
impl BackoffPolicy
Sourcepub fn jitter(&self) -> JitterPolicy
pub fn jitter(&self) -> JitterPolicy
Returns the enum value of jitter, or the default if the field is set to an invalid enum value.
Sourcepub fn set_jitter(&mut self, value: JitterPolicy)
pub fn set_jitter(&mut self, value: JitterPolicy)
Sets jitter to the provided enum value.