pub struct OutputChunk {
pub generation: u64,
pub attempt: u32,
pub stream: i32,
pub seq: u64,
pub ts: i64,
pub line: Bytes,
}Expand description
One captured line of process output.
Fields
generation: u64desired-state generation that produced the line
attempt: u32attempt within generation
stream: i32stdout or stderr
seq: u64per-stream sequence
ts: i64time the agent read the line (ms)
line: Bytesraw line content
Implementations
Sourceimpl OutputChunk
impl OutputChunk
Sourcepub fn stream(&self) -> OutputStreamKind
pub fn stream(&self) -> OutputStreamKind
Returns the enum value of stream, or the default if the field is set to an invalid enum value.
Sourcepub fn set_stream(&mut self, value: OutputStreamKind)
pub fn set_stream(&mut self, value: OutputStreamKind)
Sets stream to the provided enum value.