pub struct SelectorRequirement {
pub key: String,
pub operator: i32,
pub values: Vec<String>,
}Expand description
One set-based selector requirement.
Fields
key: Stringlabel key; non-empty
operator: i32comparison operator
values: Vec<String>required for IN / NOT_IN; empty otherwise
Implementations
Sourceimpl SelectorRequirement
impl SelectorRequirement
Sourcepub fn operator(&self) -> SelectorOperator
pub fn operator(&self) -> SelectorOperator
Returns the enum value of operator, or the default if the field is set to an invalid enum value.
Sourcepub fn set_operator(&mut self, value: SelectorOperator)
pub fn set_operator(&mut self, value: SelectorOperator)
Sets operator to the provided enum value.