pub struct TaskCondition {
pub type: String,
pub status: i32,
pub observed_generation: u64,
pub last_transition_time: i64,
pub reason: String,
pub message: String,
}Expand description
One observed condition for a Task resource.
Fields
type: Stringstable condition type
status: i32current condition status
observed_generation: u64desired generation described by this condition
last_transition_time: i64Unix time (ms)
reason: Stringstable machine-readable reason
message: Stringhuman-readable diagnostic
Implementations
Sourceimpl TaskCondition
impl TaskCondition
Sourcepub fn status(&self) -> ConditionStatus
pub fn status(&self) -> ConditionStatus
Returns the enum value of status, or the default if the field is set to an invalid enum value.
Sourcepub fn set_status(&mut self, value: ConditionStatus)
pub fn set_status(&mut self, value: ConditionStatus)
Sets status to the provided enum value.