pub struct TaskRunInfo {
pub generation: u64,
pub attempt: u32,
pub phase: i32,
pub started_at: i64,
pub finished_at: Option<i64>,
pub error: Option<String>,
pub exit_code: Option<i32>,
pub workload_api_version: String,
pub workload_kind: String,
}Expand description
History record for one finished or running attempt.
Fields
generation: u64desired-state generation executed by this run
attempt: u32attempt number within generation
phase: i32phase of this attempt
started_at: i64start time (ms)
finished_at: Option<i64>end time (ms); absent while running
error: Option<String>error message, if any
exit_code: Option<i32>process exit code, if the process exited
workload_api_version: Stringworkload GVK apiVersion captured for this run
workload_kind: Stringworkload GVK kind captured for this run
Implementations
Sourceimpl TaskRunInfo
impl TaskRunInfo
Sourcepub fn phase(&self) -> TaskPhase
pub fn phase(&self) -> TaskPhase
Returns the enum value of phase, or the default if the field is set to an invalid enum value.
Sourcepub fn finished_at(&self) -> i64
pub fn finished_at(&self) -> i64
Returns the value of finished_at, or the default value if finished_at is unset.