TaskSpec

Struct TaskSpec 

pub struct TaskSpec {
    pub slot: String,
    pub workload: Option<TaskWorkload>,
    pub timeout_ms: u64,
    pub restart: i32,
    pub restart_interval_ms: Option<u64>,
    pub backoff: Option<BackoffPolicy>,
    pub admission: i32,
    pub max_retries: Option<u32>,
    pub runner_selector: Option<LabelSelector>,
}
Desired state of a Task resource.

Fields

slot: String

execution lane; non-empty, max 64 chars

workload: Option<TaskWorkload>

versioned executable desired state; required

timeout_ms: u64

per-attempt timeout (ms); must be > 0

restart: i32

restart policy

restart_interval_ms: Option<u64>

delay between runs; ALWAYS only

backoff: Option<BackoffPolicy>

retry backoff; required

admission: i32

slot-conflict policy

max_retries: Option<u32>

failure-retry budget; omit = unlimited; 0 is invalid

runner_selector: Option<LabelSelector>

label-based runner routing; omit = any runner

Implementations

Source

impl TaskSpec

pub fn restart(&self) -> RestartPolicy

Returns the enum value of restart, or the default if the field is set to an invalid enum value.

pub fn set_restart(&mut self, value: RestartPolicy)

Sets restart to the provided enum value.

pub fn restart_interval_ms(&self) -> u64

Returns the value of restart_interval_ms, or the default value if restart_interval_ms is unset.

pub fn admission(&self) -> AdmissionPolicy

Returns the enum value of admission, or the default if the field is set to an invalid enum value.

pub fn set_admission(&mut self, value: AdmissionPolicy)

Sets admission to the provided enum value.

pub fn max_retries(&self) -> u32

Returns the value of max_retries, or the default value if max_retries is unset.