pub struct WatchTasksResponse {
pub type: i32,
pub object: Option<Task>,
}Expand description
One Task collection change.
Fields
type: i32event type
object: Option<Task>Task snapshot for this event
Implementations
Sourceimpl WatchTasksResponse
impl WatchTasksResponse
Sourcepub fn type(&self) -> TaskWatchEventType
pub fn type(&self) -> TaskWatchEventType
Returns the enum value of type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_type(&mut self, value: TaskWatchEventType)
pub fn set_type(&mut self, value: TaskWatchEventType)
Sets type to the provided enum value.