pub enum Spec {
Subprocess(SubprocessTask),
Wasm(WasmTask),
Container(ContainerTask),
Extension(ExtensionTask),
}Variants
Subprocess(SubprocessTask)
subprocess workload
Wasm(WasmTask)
WebAssembly workload
Container(ContainerTask)
OCI container workload
Extension(ExtensionTask)
application-provided workload
Implementations
Sourceimpl Spec
impl Spec
Sourcepub fn merge(
field: &mut Option<Spec>,
tag: u32,
wire_type: WireType,
buf: &mut impl Buf,
ctx: DecodeContext,
) -> Result<(), DecodeError>
pub fn merge( field: &mut Option<Spec>, tag: u32, wire_type: WireType, buf: &mut impl Buf, ctx: DecodeContext, ) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into self.
Sourcepub fn encoded_len(&self) -> usize
pub fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.