HttpApiParts

Struct HttpApiParts 

pub struct HttpApiParts {
    pub router: Router,
    pub openapi: OpenApi,
}
Standalone runtime router and its generated OpenAPI contract.

The document describes the exact routes installed on router. It is generated in memory and is not written to the source tree.

Fields

router: Router

Configured task API router.

openapi: OpenApi

OpenAPI 3.1 document for the configured router.