pub struct HttpApiParts {
pub router: Router,
pub openapi: OpenApi,
}Expand description
Standalone runtime router and its generated OpenAPI contract.
The document describes the exact routes installed on router.
It is generated in memory and is not written to the source tree.
Fields
router: RouterConfigured task API router.
openapi: OpenApiOpenAPI 3.1 document for the configured router.